// mbmac.asy
// Obecna makra pro asymptote.
// Miroslav Broz (miroslav.broz@email.cz), Apr 12th 2009

// TeX macros
texpreamble("\usepackage[utf8]{inputenc}");
texpreamble("\def\d{{\rm d}}%");
texpreamble("\newfam\vefam%");
texpreamble("\font\tenve=ugrot at 9.5pt%");
texpreamble("\font\eightve=ugrot at 7.6pt%");
texpreamble("\font\sixve=ugrot at 5.7pt%");
texpreamble("\textfont\vefam=\tenve%");
texpreamble("\scriptfont\vefam=\eightve%");
texpreamble("\scriptscriptfont\vefam=\sixve%");
texpreamble("\def\vec#1{{\fam\vefam\tenve #1}}%");

/**********************************************************************/

//defaultpen(font("csr10") + fontsize(10) + linewidth(1mm));
//defaultpen(font("csr10") + fontsize(10));
defaultpen(fontsize(10));

// default sizes
unitsize(1mm);

pen pendefault = black + linewidth(.3mm);
pen penthin = black + linewidth(.1mm);
pen penaxis = black + linewidth(.2mm);
pen penvector = black + linewidth(.4mm);
pen pendot = black + linewidth(1mm);
currentpen = penaxis;

pen dashdotted = linetype("4 1.5 0 1.5", scale=false);
pen dashed = linetype("3 1.5", scale=false);

real tmp;
real deg = pi/180;
real rad = 180/pi;
real pulcarka = .2mm;
real carka = .3mm;
real axsc = 0.7;

real arrowsizelimit=0.9;
real ahlength=2.5mm;

pair z[];
guide p[];

z[0]=(0,0);

/**********************************************************************/

// my macros

void drawcross(pair b) {
  draw (shift(b) * scale(pulcarka) * ((-1,0)--(1,0)));
  draw (shift(b) * scale(pulcarka) * ((0,-1)--(0,1)));
}

/**********************************************************************/

// vector heads (redefiniton of arrows)

path arrowhead3(path g, position position=EndPoint, pen p=currentpen,
               real size=0, real angle=arrowangle)
{
  if(size == 0) size=arrowsize(p);
  bool relative=position.relative;
  real position=position.position.x;
  if(relative) position=reltime(g,position);
  path r=subpath(g,position,0.0);
  pair x=point(r,0);
  real t=arctime(r,size);
  pair y=point(r,t);
  path base=y+2*size*I*dir(r,t)--y-2*size*I*dir(r,t);
  path left=rotate(-angle,x)*r, right=rotate(angle,x)*r;
  real[] tl=intersect(left,base), tr=intersect(right,base);
  pair denom=point(right,tr[0])-y;
  real factor=denom != 0 ? length((point(left,tl[0])-y)/denom) : 1;
  left=rotate(-angle,x)*r; right=rotate(angle*factor,x)*r;
  tl=intersect(left,base); tr=intersect(right,base);
  return subpath(left,0,tl.length > 0 ? tl[0] : 0) -- reverse(subpath(right,tr.length > 0 ? tr[0] : 0,0));
}

void arrow3(frame f, path g, pen p=currentpen, real size=0,
           real angle=arrowangle, filltype filltype=FillDraw,
           position position=EndPoint, bool forwards=true,
           margin margin=NoMargin, bool center=false)
{
  if(size == 0) size=arrowsize(p);
  size=min(arrowsizelimit*arclength(g),size);
  bool relative=position.relative;
  real position=position.position.x;
  if(relative) {
    position *= arclength(g);
    if(center) position += 0.5*size;
    position=arctime(g,position);
  } else if(center) 
    position=arctime(g,arclength(subpath(g,0,position))+0.5*size);
  g=margin(g,p).g;
  int L=length(g);
  if(!forwards) {
    g=reverse(g);
    position=L-position;
  }
  path r=subpath(g,position,0.0);
  path s=subpath(g,position,L);

  size=min(arrowsizelimit*arclength(r),size);
//  if(filltype == NoFill || position == L) {
//    draw(f,subpath(r,arctime(r,size),length(r)),p);
//    if(position < L) draw(f,s,p);
//  } else draw(f,g,p);
  draw(f,r,p);
  path head=arrowhead3(g,position,p,size,angle);
  draw(f, head, p);
//  filltype(f,head,p+solid);
}

picture arrow3(path g, pen p=currentpen, real size=0,
              real angle=arrowangle, filltype filltype=FillDraw,
              position position=EndPoint, bool forwards=true,
              margin margin=NoMargin, bool center=false)
{
  picture pic;
  pic.add(new void (frame f, transform t) {
      arrow3(f,t*g,p,size,angle,filltype,position,forwards,margin,center);
    });
  
  pic.addPath(g,p);
//  arrowheadbbox(pic,forwards ? g : reverse(g),position,p,size,angle);
  return pic;
}

arrowbar Arrow3(real size=0, real angle=arrowangle,
               filltype filltype=FillDraw, position position=EndPoint)
{
  return new bool(picture pic, path g, pen p, margin margin) {
    add(pic, arrow3(g,p,size,angle,filltype,position,margin));
    return false;
  };
}

/**********************************************************************/


