#!/usr/bin/gnuplot

# planck.plt
# Planckuv zakon B(lambda,T) a souvisejici konstanty.
# Miroslav Broz (miroslav.broz@email.cz), Apr 19th 2012

pi = 3.1415926535
h = 6.63e-34		# J.s
c = 299782458.		# m/s
k = 1.38e-23		# J/K

T_Sun = 5780.		# K, teplota Slunce
nm = 1.e-9

B(lambda,T) = 2.*h*c**2/lambda**5 * 1 / (exp(h*c/(lambda*k*T)) - 1)

# nastaveni Gnuplotu

set term post eps enh color dashed "Helvetica" 18
set out "planck.eps"
set size 0.7,0.6

set xl "{/Symbol l} / {/Symbol m}m"
set yl "{/Helvetica-Oblique B}_{/Symbol l}({/Helvetica-Oblique T}) / W m^{{/Symbol -}2} nm^{{/Symbol -}1} sr^{{/Symbol -}1}" offset 1,0

set samples 1000

nm=1.e-9
mu=1.e-6
set xr [0.5:20]
set yr [1.e-1:]
set logscale xy
set xtics (\
  "0.5"  0.5 ,\
  "1"    1.0 ,\
  "2"    2.0 ,\
  "5"    5.0 ,\
  "10"  10.0 ,\
  "20"  20.0  \
  )
set xtics add (\
  "" 0.6 1,\
  "" 0.7 1,\
  "" 0.8 1,\
  "" 0.9 1,\
  "" 3.0 1,\
  "" 4.0 1,\
  "" 6.0 1,\
  "" 7.0 1,\
  "" 8.0 1,\
  "" 9.0 1 \
  )

set style line  1 lt 1 lw 5
set style line  2 lt 2 lw 2
set style line  3 lt 4 lw 2
set style line  4 lt 8 lw 0
set style line  5 lt 6 lw 0
set style line  6 lt 7 lw 0

set lmargin 7.2
set rmargin 1.1
set bmargin 3.1
set tmargin 0.6
set grid noxtics noytics front

set label "infrared\nexcess" at 10,2.5 font "Helvetica,14" tc lt 8

p\
  (B(x*mu,1500)+B(x*mu,1000))*nm w filledcurves not        ls 4,\
  B(x*mu,1500)*nm                w filledcurves not        ls 5,\
  B(x*mu,1000)*nm                w filledcurves not        ls 6,\
  (B(x*mu,1500)+B(x*mu,1000))*nm w l            t "total"  ls 1,\
  B(x*mu,1500)*nm                w l            t "1500 K" ls 2,\
  B(x*mu,1000)*nm                w l            t "1000 K" ls 3




